==> axiom-1.3.0-src.zip: axiom-1.3.0/implementations/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DOMTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.om.impl.dom;

import javax.xml.parsers.DocumentBuilderFactory;

import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactory;
import org.apache.axiom.ts.dom.DocumentBuilderFactoryFactory;
import org.apache.axiom.ts.dom.w3c.DOMFeature;

public final class DOMTests {
    private DOMTests() {}
    
    public static final DocumentBuilderFactoryFactory FACTORY = new DocumentBuilderFactoryFactory() {
        public DocumentBuilderFactory newInstance() {
            return OMDOMMetaFactory.INSTANCE.newDocumentBuilderFactory();
        }
    };
    
    public static final DOMFeature[] UNSUPPORTED_FEATURES = {
            DOMFeature.ENTITIES, DOMFeature.NOTATIONS, DOMFeature.TYPE_INFO, DOMFeature.BASE_URI };
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/implementations/axiom-dom/src/test/java/org/apache/axiom/om/impl/dom/DOMTests.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.om.impl.dom;

import javax.xml.parsers.DocumentBuilderFactory;

import org.apache.axiom.om.impl.dom.factory.OMDOMMetaFactoryLoader;
import org.apache.axiom.ts.dom.DocumentBuilderFactoryFactory;
import org.apache.axiom.ts.dom.w3c.DOMFeature;

public final class DOMTests {
    private DOMTests() {}
    
    public static final DocumentBuilderFactoryFactory FACTORY = new DocumentBuilderFactoryFactory() {
        @Override
        public DocumentBuilderFactory newInstance() {
            return new OMDOMMetaFactoryLoader().load(null).newDocumentBuilderFactory();
        }
    };
    
    public static final DOMFeature[] UNSUPPORTED_FEATURES = {
            DOMFeature.ENTITIES, DOMFeature.NOTATIONS, DOMFeature.TYPE_INFO, DOMFeature.BASE_URI };
}
